import { Breadcrumb, BreadcrumbHint, Integration } from '@sentry/types';
/** JSDoc */
interface BreadcrumbIntegrations {
    console?: boolean;
    request?: boolean;
    navigation?: boolean;
    api?: boolean;
    lifecycle?: boolean;
}
/** Default Breadcrumbs instrumentations */
export declare class Breadcrumbs implements Integration {
    /**
     * @inheritDoc
     */
    name: string;
    /**
     * @inheritDoc
     */
    static id: string;
    /** JSDoc */
    private readonly _options;
    /**
     * @inheritDoc
     */
    constructor(options?: BreadcrumbIntegrations);
    /** JSDoc */
    private _instrumentConsole;
    /** JSDoc */
    private _instrumentRequest;
    /** JSDoc */
    private _instrumentNavigation;
    /** JSDoc */
    private _instrumentApi;
    /** JSDoc */
    private _instrumentLifecycle;
    /**
     * Helper that checks if integration is enabled on the client.
     * @param breadcrumb Breadcrumb
     * @param hint BreadcrumbHint
     */
    static addBreadcrumb(breadcrumb: Breadcrumb, hint?: BreadcrumbHint): void;
    /**
     * Instrument browser built-ins w/ breadcrumb capturing
     *  - Console API
     *  - DOM API (click/typing)
     *  - XMLHttpRequest API
     *  - Fetch API
     *  - History API
     */
    setupOnce(): void;
}
export {};
